Installation
============

Installing the application
--------------------------

From the command line:

.. code-block:: bash

   pip install papermill

Installing In-Notebook bindings
-------------------------------

* `Python <PythonBinding>`_ (included in this repo)
* `R`_ (available in the **papermillr** project)

.. _`R`: https://github.com/nteract/papermillr
